@@ -6,6 +6,7 @@ def mag(trange=['2018-10-16', '2018-10-17'],
         suffix='',  
         get_support_data=False, 
         varformat=None,
+        varnames=[],
         downloadonly=False,
         notplot=False,
         no_update=False,
@@ -36,6 +37,10 @@ def mag(trange=['2018-10-16', '2018-10-17'],
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         downloadonly: bool
             Set this flag to download the CDF files, but not load them into 
             tplot variables
@@ -53,13 +58,14 @@ def mag(trange=['2018-10-16', '2018-10-17'],
         List of tplot variables created.
 
     """
-    return load(instrument='mag', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    return load(instrument='mag', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
 def fc(trange=['2018-10-16', '2018-10-17'], 
        datatype='h1', 
        suffix='',  
        get_support_data=False, 
        varformat=None,
+       varnames=[],
        downloadonly=False,
        notplot=False,
        no_update=False,
@@ -90,6 +96,10 @@ def fc(trange=['2018-10-16', '2018-10-17'],
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         downloadonly: bool
             Set this flag to download the CDF files, but not load them into 
             tplot variables
@@ -107,13 +117,14 @@ def fc(trange=['2018-10-16', '2018-10-17'],
         List of tplot variables created.
 
     """
-    return load(instrument='faraday_cup', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    return load(instrument='faraday_cup', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
 def orb(trange=['2018-10-16', '2018-10-17'], 
        datatype='orbit', 
        suffix='',  
        get_support_data=False, 
        varformat=None,
+       varnames=[],
        downloadonly=False,
        notplot=False,
        no_update=False,
@@ -140,6 +151,10 @@ def orb(trange=['2018-10-16', '2018-10-17'],
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         downloadonly: bool
             Set this flag to download the CDF files, but not load them into 
             tplot variables
@@ -157,13 +172,14 @@ def orb(trange=['2018-10-16', '2018-10-17'],
         List of tplot variables created.
 
     """
-    return load(instrument='pre_or', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    return load(instrument='pre_or', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
 def att(trange=['2018-10-16', '2018-10-17'], 
        datatype='orbit', 
        suffix='',  
        get_support_data=False, 
        varformat=None,
+       varnames=[],
        downloadonly=False,
        notplot=False,
        no_update=False,
@@ -190,6 +206,10 @@ def att(trange=['2018-10-16', '2018-10-17'],
             The file variable formats to load into tplot.  Wildcard character
             "*" is accepted.  By default, all variables are loaded in.
 
+        varnames: list of str
+            List of variable names to load (if not specified,
+            all data variables are loaded)
+
         downloadonly: bool
             Set this flag to download the CDF files, but not load them into 
             tplot variables
@@ -207,7 +227,7 @@ def att(trange=['2018-10-16', '2018-10-17'],
         List of tplot variables created.
 
     """
-    return load(instrument='def_at', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    return load(instrument='def_at', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
 
 def all(trange=['2018-10-16', '2018-10-17'], downloadonly=False, suffix='', no_update=False, time_clip=False):
     """
