@@ -12,6 +12,7 @@ def load(trange=['2013-11-5', '2013-11-6'],
          suffix='', 
          get_support_data=False, 
          varformat=None,
+         varnames=[],
          downloadonly=False,
          notplot=False,
          no_update=False,
@@ -62,7 +63,7 @@ def load(trange=['2013-11-5', '2013-11-6'],
     if downloadonly:
         return out_files
 
-    tvars = cdf_to_tplot(out_files, suffix=suffix, merge=True, get_support_data=get_support_data, varformat=varformat, notplot=notplot)
+    tvars = cdf_to_tplot(out_files, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, notplot=notplot)
 
     if notplot:
         return tvars
